@@ -91,7 +91,9 @@ feed.parseFriendsFeedUpdate = function(response, page) {
                             "type": "feed-update",
                             "content": update
                         }
-                        page.addItem(updateitem,0);
+                        if (api.debugenabled) {
+                            page.addItem(updateitem,0);
+                        }
                     }
                 });
         } else if (prop === "deletes") {
@@ -99,12 +101,22 @@ feed.parseFriendsFeedUpdate = function(response, page) {
                 function(del) {
                     feed.log("UPDATE FEED TYPE: " + del.type);
                     feed.debug(function(){ return "UPDATE CONTENT: " + JSON.stringify(del)});
-                    del.debugType = "feed-delete";
-                    var deleteitem = {
-                        "type": "feed-delete",
-                        "content": del
+                    if (del.type === "photo") {
+                        //do nothing, just skip that.
+                    } else if (del.type === "checkin") {
+                        page.deleteItem(del.id);
+                    } else if (del.type === "activity"){
+                        page.deleteItem(del.id);
+                    } else {
+                        del.debugType = "feed-delete";
+                        var deleteitem = {
+                            "type": "feed-delete",
+                            "content": del
+                        }
+                        if (api.debugenabled) {
+                            page.addItem(deleteitem,0);
+                        }
                     }
-                    page.addItem(deleteitem,0);
                 });
         } else {
             feed.log("UPDATE TYPE: " + prop);
@@ -116,7 +128,9 @@ feed.parseFriendsFeedUpdate = function(response, page) {
                 "type": "feed-" + prop,
                 "content": propdata
             }
-            page.addItem(propitem,0);
+            if (api.debugenabled) {
+                page.addItem(propitem,0);
+            }
         }
     }
 }
@@ -293,7 +307,9 @@ feed.feedObjParserUnknown = function(page, object) {
         "type": object.type,
         "content": object
     }
-    page.addItem(item);
+    if (api.debugenabled) {
+        page.addItem(item);
+    }
 }
 
 feed.feedObjParserCheckin = function(page, object) {
