@@ -33,6 +33,17 @@ Cache::Cache(QObject *parent) :
     connect(manager,SIGNAL(finished(QNetworkReply*)),SLOT(onDownloadFinished(QNetworkReply*)));
 }
 
+QVariant Cache::getFile(QVariant url)
+{
+    QString data;
+    QFile file(url.toString());
+    if (file.exists()) {
+        file.open(QIODevice::ReadOnly);
+        data = file.readAll();
+    }
+    return QVariant(data);
+}
+
 QVariant Cache::loadtype(QVariant _type) {
     QString type = _type.toString();
     if (type == "all") {
@@ -54,16 +65,16 @@ void Cache::onDownloadFinished(QNetworkReply * reply){
         return;
     }
     QString url = reply->request().url().toString();
-    QString name = makeCachedURL(url);
+    QString namelocal = makeCachedURL(url);
 
     {
-        QFile file(name);
+        QFile file(namelocal);
         file.open(QFile::WriteOnly);
         file.write(data);
     }
 
     m_cachemap_lock.lockForWrite();
-    m_cachemap.insert(url,name);
+    m_cachemap.insert(url,namelocal);
     m_cachemap_lock.unlock();
     makeCallbackAll(true,url);
 }
@@ -78,12 +89,13 @@ QString Cache::md5(QString data)
 QString Cache::makeCachedURL(QString url)
 {
     QString ext = url.right(url.size() - url.lastIndexOf("."));
+    ext = ext.left(ext.indexOf("/"));
     return m_path + "/" + md5(url) + ext;
 }
 
-QVariant Cache::removeUrl(QVariant data)
+QVariant Cache::removeUrl(QVariant dataurl)
 {
-    QString url = data.toString();
+    QString url = dataurl.toString();
     if (url.size()) {
         m_cachemap_lock.lockForWrite();
         m_cachemap.remove(url);
@@ -93,45 +105,54 @@ QVariant Cache::removeUrl(QVariant data)
     return QVariant(true);
 }
 
-void Cache::queueObject(QVariant data, QVariant callback)
+void Cache::queueObject(QVariant dataurl, QVariant callback)
 {
     //qDebug() << "QueueObject callback: " << callback;
-    QString url = data.toString();
+    QString namelocal;
+    QString url = dataurl.toString();
     if (url.size()) {
         m_cachemap_lock.lockForRead();
         QMap<QString,QString>::iterator it = m_cachemap.find(url);
         if (it!=m_cachemap.end()) {
             //qDebug() << "cache hit" << url;
-            data = it.value();
+            namelocal = it.value();
             m_cachemap_lock.unlock();
-            makeCallback(callback,true,data);
+            makeCallback(callback,true,namelocal);
         } else {
             //qDebug() << "cache miss" << url;
-            QString name = makeCachedURL(url);
-            QFileInfo file(name);
+            namelocal = makeCachedURL(url);
             //qDebug() << "Hash:" << name << "Status:" << file.exists() << "URL:" << url;
+#ifndef Q_WS_SIMULATOR
+            {
+                QFileInfo fileinfo(namelocal);
+                QDateTime modif = fileinfo.lastModified();
+                if (modif.daysTo(QDateTime::currentDateTime()) > CACHE_DAY_DURATION) {
+                    QFile(fileinfo.absoluteFilePath()).remove();
+                }
+            }
+#endif
+            QFileInfo file(namelocal);
             if (file.exists()) {
-                data = QVariant(name);
                 m_cachemap_lock.unlock();
                 m_cachemap_lock.lockForWrite();
-                m_cachemap.insert(url,name);
+                m_cachemap.insert(url,namelocal);
                 m_cachemap_lock.unlock();
-                makeCallback(callback,true,data);
+                makeCallback(callback,true,namelocal);
             } else {
+                m_cachemap_lock.unlock();
                 if (m_cacheonly) {
-                    data = QVariant("");
+                    dataurl = QVariant("");
                 } else {
                     //add to queue, post and download query
-                    if (queueCacheUpdate(data, callback)) {
+                    if (queueCacheUpdate(dataurl, callback)) {
                         //qDebug() << "download " << url;
                         manager->get(QNetworkRequest(QUrl(url)));
                     }
                 }
-                m_cachemap_lock.unlock();
             }            
         }
     } else {
-        makeCallback(callback,false,data);
+        makeCallback(callback,false,dataurl);
     }
 }
 
@@ -179,10 +200,11 @@ void Cache::makeCallbackAll(bool status, QVariant url)
         m_cachequeue_lock.unlock();
         return;
     }
+    QString namelocal = makeCachedURL(url.toString());
     CCallbackList &callbacks = *it;
     CCallbackList::iterator itc = callbacks.begin();
     while(itc!=callbacks.end()) {
-        makeCallback(*itc,status,url.toString());
+        makeCallback(*itc,status,namelocal);
         itc++;
     }
     m_cachequeue_lock.unlock();
@@ -206,13 +228,7 @@ QVariant Cache::info()
     dir.setFilter(QDir::Files | QDir::Hidden | QDir::NoSymLinks);
     QFileInfoList list = dir.entryInfoList();
     for (int i=0; i<list.size();i++) {
-        QDateTime modif = list.at(i).lastModified();
-        if (modif.daysTo(today) > 14) {
-            QFile(list.at(i).absoluteFilePath()).remove();
-        }
-        else {
             total += list.at(i).size();
-        }
     }
 
     double result = double(total) / 1000000;
